@@ -26,25 +26,25 @@ from ..htmlutil import linkparse
 class AnchorCheck(_ContentPlugin):
     """Checks validity of HTML anchors."""
 
-    def __init__(self, config):
-        """Initialize plugin."""
-        super().__init__(config)
-        log.warn(
-            LOG_PLUGIN, _("Anchor check plugin is broken. Fixes welcome.")
-        )
-
     def applies_to(self, url_data):
         """Check for HTML anchor existence."""
-        return False  # XXX Plugin disabled
         return url_data.is_html() and url_data.anchor
 
     def check(self, url_data):
         """Check content for invalid anchors."""
         log.debug(LOG_PLUGIN, "checking content for invalid anchors")
+        url_anchor_check = UrlAnchorCheck()
+        linkparse.find_links(
+            url_data.get_soup(), url_anchor_check.add_anchor, linkparse.AnchorTags)
+        url_anchor_check.check_anchor(url_data)
+
+
+class UrlAnchorCheck:
+    """Class to thread-safely handle collecting anchors for a URL"""
+
+    def __init__(self):
         # list of parsed anchors
         self.anchors = []
-        linkparse.find_links(url_data.get_soup(), self.add_anchor, linkparse.AnchorTags)
-        self.check_anchor(url_data)
 
     def add_anchor(self, url, line, column, name, base):
         """Add anchor URL."""
@@ -54,17 +54,20 @@ class AnchorCheck(_ContentPlugin):
         """If URL is valid, parseable and has an anchor, check it.
         A warning is logged and True is returned if the anchor is not found.
         """
-        log.debug(LOG_PLUGIN, "checking anchor %r in %s", url_data.anchor, self.anchors)
-        if any(x for x in self.anchors if urllib.parse.quote(x[0]) == url_data.anchor):
+        decoded_anchor = urllib.parse.unquote(
+            url_data.anchor, encoding=url_data.encoding)
+        log.debug(LOG_PLUGIN, "checking anchor %r (decoded: %r) in %s",
+                  url_data.anchor, decoded_anchor, self.anchors)
+        if any(x for x in self.anchors if x[0] == decoded_anchor):
             return
         if self.anchors:
-            anchornames = sorted(set("`%s'" % x[0] for x in self.anchors))
+            anchornames = sorted({f"`{x[0]}'" for x in self.anchors})
             anchors = ", ".join(anchornames)
         else:
             anchors = "-"
-        args = {"name": url_data.anchor, "anchors": anchors}
-        msg = "%s %s" % (
-            _("Anchor `%(name)s' not found.") % args,
+        args = {"name": url_data.anchor, "decoded": decoded_anchor, "anchors": anchors}
+        msg = "{} {}".format(
+            _("Anchor `%(name)s' (decoded: `%(decoded)s') not found.") % args,
             _("Available anchors: %(anchors)s.") % args,
         )
         url_data.add_warning(msg)
