@@ -1,4 +1,3 @@
-# -*- coding: iso-8859-1 -*-
 # Copyright (C) 2005-2014 Bastian Kleineidam
 #
 # This program is free software; you can redistribute it and/or modify
@@ -17,25 +16,24 @@
 """
 Simple decorators (usable in Python >= 2.4).
 
-Example:
+Example::
 
-@synchronized(thread.allocate_lock())
-def f ():
-    "Synchronized function"
-    print("i am synchronized:", f, f.__doc__)
+    @synchronized(thread.allocate_lock())
+    def f():
+        "Synchronized function"
+        print("i am synchronized:", f, f.__doc__)
 
-@deprecated
-def g ():
-    "this function is deprecated"
-    pass
+    @deprecated
+    def g():
+        "this function is deprecated"
+        pass
 
-@notimplemented
-def h ():
-    "todo"
-    pass
+    @notimplemented
+    def h():
+        "todo"
+        pass
 
 """
-from __future__ import print_function
 import warnings
 import signal
 import os
@@ -43,7 +41,7 @@ import sys
 import time
 
 
-def update_func_meta (fake_func, real_func):
+def update_func_meta(fake_func, real_func):
     """Set meta information (eg. __doc__) of fake function to that
     of the real function.
     @return fake_func
@@ -55,18 +53,22 @@ def update_func_meta (fake_func, real_func):
     return fake_func
 
 
-def deprecated (func):
+def deprecated(func):
     """A decorator which can be used to mark functions as deprecated.
     It emits a warning when the function is called."""
-    def newfunc (*args, **kwargs):
+
+    def newfunc(*args, **kwargs):
         """Print deprecated warning and execute original function."""
-        warnings.warn("Call to deprecated function %s." % func.__name__,
-                      category=DeprecationWarning)
+        warnings.warn(
+            "Call to deprecated function %s." % func.__name__,
+            category=DeprecationWarning,
+        )
         return func(*args, **kwargs)
+
     return update_func_meta(newfunc, func)
 
 
-def signal_handler (signal_number):
+def signal_handler(signal_number):
     """From http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/410666
 
     A decorator to set the specified function as handler for a signal.
@@ -76,7 +78,7 @@ def signal_handler (signal_number):
     no handler is set.
     """
     # create the 'real' decorator which takes only a function as an argument
-    def newfunc (function):
+    def newfunc(function):
         """Register function as signal handler."""
         # note: actually the kill(2) function uses the signal number of 0
         # for a special case, but for signal(2) only positive integers
@@ -85,41 +87,51 @@ def signal_handler (signal_number):
         if is_valid_signal and os.name == 'posix':
             signal.signal(signal_number, function)
         return function
+
     return newfunc
 
 
-def synchronize (lock, func, log_duration_secs=0):
+def synchronize(lock, func, log_duration_secs=0):
     """Return synchronized function acquiring the given lock."""
-    def newfunc (*args, **kwargs):
+
+    def newfunc(*args, **kwargs):
         """Execute function synchronized."""
         t = time.time()
         with lock:
             duration = time.time() - t
             if duration > log_duration_secs > 0:
-                print("WARN:", func.__name__, "locking took %0.2f seconds" % duration, file=sys.stderr)
+                print(
+                    "WARN:",
+                    func.__name__,
+                    "locking took %0.2f seconds" % duration,
+                    file=sys.stderr,
+                )
             return func(*args, **kwargs)
+
     return update_func_meta(newfunc, func)
 
 
-def synchronized (lock):
-    """A decorator calling a function with aqcuired lock."""
+def synchronized(lock):
+    """A decorator calling a function with acquired lock."""
     return lambda func: synchronize(lock, func)
 
 
-def notimplemented (func):
+def notimplemented(func):
     """Raises a NotImplementedError if the function is called."""
-    def newfunc (*args, **kwargs):
+
+    def newfunc(*args, **kwargs):
         """Raise NotImplementedError"""
         co = func.func_code
         attrs = (co.co_name, co.co_filename, co.co_firstlineno)
         raise NotImplementedError("function %s at %s:%d is not implemented" % attrs)
+
     return update_func_meta(newfunc, func)
 
 
-def timeit (func, log, limit):
+def timeit(func, log, limit):
     """Print execution time of the function. For quick'n'dirty profiling."""
 
-    def newfunc (*args, **kwargs):
+    def newfunc(*args, **kwargs):
         """Execute function and print execution time."""
         t = time.time()
         res = func(*args, **kwargs)
@@ -129,43 +141,16 @@ def timeit (func, log, limit):
             print(args, file=log)
             print(kwargs, file=log)
         return res
+
     return update_func_meta(newfunc, func)
 
 
-def timed (log=sys.stderr, limit=2.0):
+def timed(log=sys.stderr, limit=2.0):
     """Decorator to run a function with timing info."""
     return lambda func: timeit(func, log, limit)
 
 
-class memoized (object):
-    """Decorator that caches a function's return value each time it is called.
-    If called later with the same arguments, the cached value is returned, and
-    not re-evaluated."""
-
-    def __init__(self, func):
-        """Store function and initialize the cache."""
-        self.func = func
-        self.cache = {}
-
-    def __call__(self, *args):
-        """Lookup and return cached result if found. Else call stored
-        function with given arguments."""
-        try:
-            return self.cache[args]
-        except KeyError:
-            self.cache[args] = value = self.func(*args)
-            return value
-        except TypeError:
-            # uncachable -- for instance, passing a list as an argument.
-            # Better to not cache than to blow up entirely.
-            return self.func(*args)
-
-    def __repr__(self):
-        """Return the function's docstring."""
-        return self.func.__doc__
-
-
-class curried (object):
+class curried:
     """Decorator that returns a function that keeps returning functions
     until all arguments are supplied; then the original function is
     evaluated."""
