@@ -8,19 +8,12 @@ Example usage::
     plugins = loader.get_plugins(modules, PluginClass)
 """
 import os
-import sys
-import zipfile
-import importlib
+import importlib.util
+import pkgutil
 
 from .fileutil import is_writable_by_others
 
 
-def is_frozen():
-    """Return True if running inside a py2exe- or py2app-generated
-    executable."""
-    return hasattr(sys, "frozen")
-
-
 def check_writable_by_others(filename):
     """Check if file is writable by others on POSIX systems.
     On non-POSIX systems the check is ignored."""
@@ -30,7 +23,7 @@ def check_writable_by_others(filename):
     return is_writable_by_others(filename)
 
 
-def get_package_modules(packagename):
+def get_package_modules(packagename, packagepath):
     """Find all valid modules in the given package which must be a folder
     in the same directory as this loader.py module. A valid module has
     a .py extension, and is importable.
@@ -38,26 +31,13 @@ def get_package_modules(packagename):
     @return: all loaded valid modules
     @rtype: iterator of module
     """
-    if is_frozen():
-        # find modules in library.zip filename
-        zipname = os.path.dirname(os.path.dirname(__file__))
-        parentmodule = os.path.basename(os.path.dirname(__file__))
-        with zipfile.ZipFile(zipname, 'r') as f:
-            prefix = "%s/%s/" % (parentmodule, packagename)
-            modnames = [
-                os.path.splitext(n[len(prefix):])[0]
-                for n in f.namelist()
-                if n.startswith(prefix) and "__init__" not in n
-            ]
-    else:
-        dirname = os.path.join(os.path.dirname(__file__), packagename)
-        modnames = [x[:-3] for x in get_importable_files(dirname)]
-    for modname in modnames:
-        try:
-            name = "..%s.%s" % (packagename, modname)
-            yield importlib.import_module(name, __name__)
-        except ImportError as msg:
-            print("WARN: could not load module %s: %s" % (modname, msg))
+    for mod in pkgutil.iter_modules(packagepath):
+        if not mod.ispkg:
+            try:
+                name = f"..{packagename}.{mod.name}"
+                yield importlib.import_module(name, __name__)
+            except ImportError as msg:
+                print(_("WARN: could not load module %s: %s") % (mod.name, msg))
 
 
 def get_folder_modules(folder, parentpackage):
@@ -74,7 +54,7 @@ def get_folder_modules(folder, parentpackage):
             spec.loader.exec_module(module)
             yield module
         except ImportError as msg:
-            print("WARN: could not load file %s: %s" % (fullname, msg))
+            print(_("WARN: could not load file %s: %s") % (fullname, msg))
 
 
 def get_importable_files(folder):
@@ -105,8 +85,7 @@ def get_plugins(modules, classes):
     @rtype: iterator of class objects
     """
     for module in modules:
-        for plugin in get_module_plugins(module, classes):
-            yield plugin
+        yield from get_module_plugins(module, classes)
 
 
 def get_module_plugins(module, classes):
